SplitContainer Widget Demo

# Dijit Split Container Test - DEPRECATED!

dijit.layout.SplitContainer is deprecated use BorderContainer with splitter instead -- will be removed in version: 2

HTML before

this box has three split panes
in vertical mode
without active resizing
this box has two horizontal panes
with active resizing, a smaller sizer, different starting sizes and minimum sizes

HTML after

the following splitter contains two iframes, see whether the resizer works ok in this situation

### Programatic Example: